==> mili-4.0.1.tgz: package/es/src/upgrade.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as fs from 'fs-extra';
import { migrate } from "./migrate";
import { render } from "./render";
import { check } from "./util/check";
import { copy } from "./util/copy";
import { createTmpDir } from "./util/create-tmp-dir";
import { parseTemplate } from "./util/parse-template";
import { syncDir } from "./util/sync-dir";
export function upgrade(options, version = 'latest') {
    return __awaiter(this, void 0, void 0, function* () {
        const { template, version: fromVersion = 'latest', cwd = process.cwd(), force = false, answers = {}, } = options;
        if (!force)
            yield check(cwd);
        const tmpDir = yield createTmpDir();
        yield copy(cwd, tmpDir);
        const repository = parseTemplate(template, version);
        yield render(tmpDir, repository, answers);
        yield migrate(tmpDir, repository, fromVersion);
        yield syncDir(tmpDir, cwd);
        yield fs.remove(tmpDir);
    });
}

==> mili-4.2.1.tgz: package/es/src/upgrade.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as fs from 'fs-extra';
import { migrate } from "./migrate";
import { render } from "./render";
import { check } from "./util/check";
import { copy } from "./util/copy";
import { createTmpDir } from "./util/create-tmp-dir";
import { parseTemplate } from "./util/parse-template";
import { syncDir } from "./util/sync-dir";
export function upgrade(options, version = 'latest') {
    return __awaiter(this, void 0, void 0, function* () {
        const { template, version: fromVersion = 'latest', cwd = process.cwd(), force = false, answers = {}, } = options;
        if (!force)
            yield check(cwd);
        const tmpDir = yield createTmpDir();
        yield copy(cwd, tmpDir, true);
        const repository = parseTemplate(template, version);
        yield render(tmpDir, repository, answers);
        yield migrate(tmpDir, repository, fromVersion);
        yield syncDir(tmpDir, cwd);
        yield fs.remove(tmpDir);
    });
}
